/*
 * Copyright (C) 2003 Jelmer Vernooij <jelmer@samba.org>
 */

#ifndef _KREGEDITVIEW_H_
#define _KREGEDITVIEW_H_

#include <qwidget.h>
#include <kparts/part.h>
#include <kregeditiface.h>

#include "editreg.h"

class QPainter;
class KURL;
class KListView;
class KListViewItem;
class QListViewItem;

/**
 * This is the main view class for kregedit.  Most of the non-menu,
 * non-toolbar, and non-statusbar (e.g., non frame) GUI code should go
 * here.
 *
 *
 * @short Main view
 * @author Jelmer Vernooij <jelmer@samba.org>
 * @version 0.1
 */
class kregeditView : public QWidget, public kregeditIface
{
    Q_OBJECT
public:
	/**
	 * Default constructor
	 */
    kregeditView(QWidget *parent);

	/**
	 * Destructor
	 */
    virtual ~kregeditView();

    /**
     * Random 'get' function
     */
    QString currentURL();

    /**
     * Random 'set' function accessed by DCOP
     */
    virtual void openURL(QString url);

    /**
     * Random 'set' function
     */
    virtual void openURL(const KURL& url);

    /**
     * Save to specified URL
     */

    virtual void saveURL(QString url);

    /**
     * Save to specified real URL
     */
    virtual void saveURL(const KURL& url);

    /**
     * Save to current URL
     */
    virtual void save();

    /**
     * Print this view to any medium -- paper or not
     */
    void print(QPainter *, int height, int width);

	/**
	 * Add key to tree KListView. Defaults to root
	 */
	void addKey(KListViewItem *_parent = 0, REG_KEY *_key = 0);

signals:
    /**
     * Use this signal to change the content of the statusbar
     */
    void signalChangeStatusbar(const QString& text);

    /**
     * Use this signal to change the content of the caption
     */
    void signalChangeCaption(const QString& text);

private slots:
    void slotOnURL(const QString& url);
    void slotSetTitle(const QString& title);
    void viewVals( QListViewItem *item );

private:
	REGF *regf;
	KURL url;
	KListView *tree;
	KListView *keys;
};

#endif // _KREGEDITVIEW_H_
